@@ -1,6 +1,4 @@
-#! /bin/sh
-# The next line restarts with tclsh \
-exec tclsh "$0" ${1+"$@"}
+#! /usr/bin/env tclsh
 
 package require Tk
 
