@@ -1,17 +1,17 @@
-#!/usr/bin/env wish
+#! /usr/bin/env tclsh
 
 #==============================================================================
 # Demonstrates the use of the Scrollutil package in connection with the BWidget
 # ScrollableFrame widget.
 #
-# Copyright (c) 2019-2022  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2019-2023  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
-package require Tk 8.5.9			;# for ttk::spinbox
+package require Tk 8.5.9-			;# for ttk::spinbox
 package require BWidget
 Widget::theme yes
-package require mentry_tile 3.2			;# for mouse wheel support
-package require tablelist_tile 6.5		;# for -(x|y)mousewheelwindow
+package require mentry_tile 3.2-		;# for mouse wheel support
+package require tablelist_tile 6.5-		;# for -(x|y)mousewheelwindow
 						;# and scrollutil::scrollarea
 package require scrollutil_tile
 set dir [file dirname [info script]]
