@@ -1,14 +1,14 @@
-#!/usr/bin/env wish
+#! /usr/bin/env tclsh
 
 #==============================================================================
 # Demonstrates the traditional scrollbar management in connection with a
 # tablelist widget.
 #
-# Copyright (c) 2019-2022  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2019-2024  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
-package require Tk 8.5
-package require tablelist_tile 6.3
+package require Tk 8.5-
+package require tablelist_tile 6.3-
 set dir [file dirname [info script]]
 source [file join $dir styleUtil.tcl]
 
@@ -29,7 +29,7 @@ tablelist::tablelist $tbl \
     -titlecolumns 1 -borderwidth 0 \
     -xscrollcommand [list $hsb set] -yscrollcommand [list $vsb set]
 switch [tk windowingsystem] {
-    x11   { set width 53 }
+    x11   { set width 54 }
     win32 { set width 58 }
     aqua  { set width 51 }
 }
