@@ -1,12 +1,13 @@
-#!/usr/bin/env wish
+#! /usr/bin/env tclsh
 
 #==============================================================================
 # Demonstrates the use of the scrollutil::scrollsync widget in connection with
 # two listbox widgets.
 #
-# Copyright (c) 2019-2022  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2019-2023  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
+package require Tk
 package require scrollutil_tile
 set dir [file dirname [info script]]
 source [file join $dir styleUtil.tcl]
