@@ -7,7 +7,7 @@
 #   - Private procedures related to tile themes
 #   - Private procedures related to global KDE configuration options
 #
-# Copyright (c) 2006-2022  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2006-2024  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
 #
@@ -181,6 +181,7 @@ proc mentry::aquaTheme {} {
 	}
 
 	if {$extendedAquaSupport} {
+	    ##nagelfar ignore
 	    scan $::tcl_platform(osVersion) "%d" majorOSVersion
 	    set labelPadY [expr {$majorOSVersion >= 18 ? {4 7} : {4 5}}]
 	} else {
@@ -277,6 +278,61 @@ proc mentry::blueTheme {} {
     ]
 }
 
+#------------------------------------------------------------------------------
+# mentry::blackTheme
+#------------------------------------------------------------------------------
+proc mentry::blackTheme {} {
+    variable themeDefaults
+    array set themeDefaults [list \
+	-background		#ffffff \
+	-disabledforeground	#a9a9a9 \
+	-selectbackground	#4a6984 \
+	-selectforeground	#ffffff \
+	-selectborderwidth	0 \
+	-borderwidth		2 \
+	-labelpady		{2 2} \
+    ]
+}
+
+#------------------------------------------------------------------------------
+# mentry::BreezeTheme, mentry::breezeTheme
+#------------------------------------------------------------------------------
+proc mentry::BreezeTheme {} {
+    variable themeDefaults
+    array set themeDefaults [list \
+	-background		#fcfcfc \
+	-readonlybackground	#fcfcfc \
+	-disabledbackground	#eff0f1 \
+	-disabledforeground	#bbcbbe \
+	-selectbackground	#3daee9 \
+	-selectforeground	#ffffff \
+	-selectborderwidth	0 \
+	-borderwidth		2 \
+	-labelpady		{2 2} \
+    ]
+}
+proc mentry::breezeTheme {} {
+    BreezeTheme
+}
+
+#------------------------------------------------------------------------------
+# mentry::breeze-darkTheme
+#------------------------------------------------------------------------------
+proc mentry::breeze-darkTheme {} {
+    variable themeDefaults
+    array set themeDefaults [list \
+	-background		#2f3336 \
+	-readonlybackground	#2f3336 \
+	-disabledbackground	#31363b \
+	-disabledforeground	#7f8c8d \
+	-selectbackground	#3daee9 \
+	-selectforeground	#ffffff \
+	-selectborderwidth	0 \
+	-borderwidth		2 \
+	-labelpady		{2 2} \
+    ]
+}
+
 #------------------------------------------------------------------------------
 # mentry::clamTheme
 #------------------------------------------------------------------------------
@@ -302,10 +358,18 @@ proc mentry::classicTheme {} {
 	-disabledforeground	#a3a3a3 \
 	-selectbackground	#c3c3c3 \
 	-selectforeground	#000000 \
-	-selectborderwidth	1 \
-	-borderwidth		3 \
-	-labelpady		{3 3} \
     ]
+
+    set val [styleConfig . -selectborderwidth]
+    set themeDefaults(-selectborderwidth) [expr {$val eq "" ? 0 : $val}]
+
+    if {[styleConfig . -borderwidth] == 1} {
+	set themeDefaults(-borderwidth) 2
+	set themeDefaults(-labelpady)	{2 2}
+    } else {
+	set themeDefaults(-borderwidth)	3
+	set themeDefaults(-labelpady)	{3 3}
+    }
 }
 
 #------------------------------------------------------------------------------
@@ -334,10 +398,18 @@ proc mentry::defaultTheme {} {
 	-disabledforeground	#a3a3a3 \
 	-selectbackground	#4a6984 \
 	-selectforeground	#ffffff \
-	-selectborderwidth	1 \
-	-borderwidth		1 \
-	-labelpady		{1 1} \
     ]
+
+    set val [styleConfig . -selectborderwidth]
+    set themeDefaults(-selectborderwidth) [expr {$val eq "" ? 0 : $val}]
+
+    if {[styleConfig TEntry -focuswidth] eq ""} {
+	set themeDefaults(-borderwidth)       1
+	set themeDefaults(-labelpady)         {1 1}
+    } else {
+	set themeDefaults(-borderwidth)       2
+	set themeDefaults(-labelpady)         {2 2}
+    }
 }
 
 #------------------------------------------------------------------------------
@@ -447,6 +519,44 @@ proc mentry::stepTheme {} {
     ]
 }
 
+#------------------------------------------------------------------------------
+# mentry::sun-valley-lightTheme
+#------------------------------------------------------------------------------
+proc mentry::sun-valley-lightTheme {} {
+    variable themeDefaults
+    array set themeDefaults [list \
+	-background		#fdfdfd \
+	-readonlybackground	#fdfdfd \
+	-disabledbackground	#fafafa \
+	-disabledforeground	#a0a0a0 \
+	-selectbackground	#2f60d8 \
+	-selectforeground	#ffffff \
+	-font			SunValleyBodyFont \
+	-selectborderwidth	0 \
+	-borderwidth		2 \
+	-labelpady		{2 2} \
+    ]
+}
+
+#------------------------------------------------------------------------------
+# mentry::sun-valley-darkTheme
+#------------------------------------------------------------------------------
+proc mentry::sun-valley-darkTheme {} {
+    variable themeDefaults
+    array set themeDefaults [list \
+	-background		#292929 \
+	-readonlybackground	#292929 \
+	-disabledbackground	#262626 \
+	-disabledforeground	#595959 \
+	-selectbackground	#2f60d8 \
+	-selectforeground	#ffffff \
+	-font			SunValleyBodyFont \
+	-selectborderwidth	0 \
+	-borderwidth		2 \
+	-labelpady		{2 2} \
+    ]
+}
+
 #------------------------------------------------------------------------------
 # mentry::tileqtTheme
 #------------------------------------------------------------------------------
