@@ -4,6 +4,6 @@
 # Copyright (c) 2020-2024  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
-package ifneeded mwutil     2.22 [list source [file join $dir mwutil.tcl]]
-package ifneeded scaleutil  1.13 [list source [file join $dir scaleutil.tcl]]
-package ifneeded themepatch 1.6  [list source [file join $dir themepatch.tcl]]
+package ifneeded mwutil     2.23   [list source [file join $dir mwutil.tcl]]
+package ifneeded scaleutil  1.14.1 [list source [file join $dir scaleutil.tcl]]
+package ifneeded themepatch 1.8    [list source [file join $dir themepatch.tcl]]
