@@ -5,7 +5,7 @@
 # scrolledframe::scrolledframe command of the Scrolledframe package by Maurice
 # Bredelet (ulis) and its optimized and enhanced version contributed by Keith
 # Nash, as well as with the sframe command implemented by Paul Walton (see
-# https://wiki.tcl-lang.org/ page/A+scrolled+frame).
+# https://wiki.tcl-lang.org/page/A+scrolled+frame).
 #
 # Structure of the module:
 #   - Namespace initialization
@@ -13,25 +13,31 @@
 #   - Public procedures
 #   - Private procedures
 #
-# Copyright (c) 2019-2020  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2019-2024  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
-package require Tk 8.4
-
 #
 # Namespace initialization
 # ========================
 #
 
 namespace eval scrollutil {
-    variable winSys [tk windowingsystem]
-
     #
     # The list of scrollable widget containers that are
     # registered for scrolling by the mouse wheel event
     # bindings created by the createWheelEventBindings command:
     #
     variable scrlWidgetContList {}
+
+    variable uniformWheelSupport [expr {$::tk_version >= 8.7 &&
+	[package vcompare $::tk_patchLevel "8.7a4"] >= 0}]
+
+    variable touchpadScrollSupport [expr {
+	[llength [info commands ::tk::PreciseScrollDeltas]] != 0}]
+
+    variable scrollByUnitsProc [expr {
+	[llength [info commands ::tk::ScrollByUnits]] == 0 ?
+	"tkScrollByUnits" : "tk::ScrollByUnits"}]
 }
 
 #
@@ -48,47 +54,97 @@ namespace eval scrollutil {
 #------------------------------------------------------------------------------
 proc scrollutil::createBindings {} {
     variable winSys
+    variable uniformWheelSupport
 
     #
-    # On the windowing systems win32 and x11 there are no built-in
-    # mouse wheel event bindings for the binding tag Scrollbar
-    # if the Tk version is earlier than 8.6 -- create them here
+    # On the windowing systems win32 and x11 there are no built-in mouse wheel
+    # event bindings for the binding tag Scrollbar if the Tk version is earlier
+    # than 8.6 -- create them here.  In addition, implement the behavior
+    # specified by TIP 563 (i.e., the mouse wheel should scroll a horizontal or
+    # vertical scrollbar regardless of whether the "Shift" key is down or not)
     #
-    if {$winSys eq "win32" || $winSys eq "x11"} {
-	set scrollByUnits [expr {
-	    [llength [info commands ::tk::ScrollByUnits]] == 0 ?
-	    "tkScrollByUnits" : "tk::ScrollByUnits"}]
+    bind Scrollbar <Enter> {+
+	if {![info exists tk::Priv(xEvents)]} {
+	    set scrollutil::xWheelEvents 0; set scrollutil::yWheelEvents 0
+	}
+    }
+    if {$uniformWheelSupport} {
+	bind Scrollbar <MouseWheel> {
+	    scrollutil::condScrollByUnits %W vh %D -40.0
+	}
+	bind Scrollbar <Option-MouseWheel> {
+	    scrollutil::condScrollByUnits %W vh %D -12.0
+	}
+	bind Scrollbar <Shift-MouseWheel> {
+	    scrollutil::condScrollByUnits %W hv %D -40.0
+	}
+	bind Scrollbar <Shift-Option-MouseWheel> {
+	    scrollutil::condScrollByUnits %W hv %D -12.0
+	}
+    } else {
+	if {$winSys eq "aqua"} {
+	    bind Scrollbar <MouseWheel> {
+		scrollutil::condScrollByUnits %W vh [expr {-(%D)}]
+	    }
+	    bind Scrollbar <Option-MouseWheel> {
+		scrollutil::condScrollByUnits %W vh [expr {-10 * (%D)}]
+	    }
+	    bind Scrollbar <Shift-MouseWheel> {
+		scrollutil::condScrollByUnits %W hv [expr {-(%D)}]
+	    }
+	    bind Scrollbar <Shift-Option-MouseWheel> {
+		scrollutil::condScrollByUnits %W hv [expr {-10 * (%D)}]
+	    }
+	} else {
+	    bind Scrollbar <MouseWheel> {
+		scrollutil::condScrollByUnits %W vh \
+		    [expr {%D >= 0 ? (-%D) / 30 : (-(%D) + 29) / 30}]
+	    }
+	    bind Scrollbar <Shift-MouseWheel> {
+		scrollutil::condScrollByUnits %W hv \
+		    [expr {%D >= 0 ? (-%D) / 30 : (-(%D) + 29) / 30}]
+	    }
 
-	bind Scrollbar <MouseWheel> [format {
-	    %s %%W v [expr {%%D >= 0 ? (-%%D) / 30 : (-(%%D) + 29) / 30}]
-	} $scrollByUnits]
-	bind Scrollbar <Shift-MouseWheel> [format {
-	    %s %%W h [expr {%%D >= 0 ? (-%%D) / 30 : (-(%%D) + 29) / 30}]
-	} $scrollByUnits]
+	    if {$winSys eq "x11"} {
+		bind Scrollbar <Button-4> {
+		    scrollutil::condScrollByUnits %W vh -5
+		}
+		bind Scrollbar <Button-5> {
+		    scrollutil::condScrollByUnits %W vh  5
+		}
+		bind Scrollbar <Shift-Button-4> {
+		    scrollutil::condScrollByUnits %W hv -5
+		}
+		bind Scrollbar <Shift-Button-5> {
+		    scrollutil::condScrollByUnits %W hv  5
+		}
 
-	if {$winSys eq "x11"} {
-	    bind Scrollbar <Button-4>	    [list $scrollByUnits %W v -5]
-	    bind Scrollbar <Button-5>	    [list $scrollByUnits %W v  5]
-	    bind Scrollbar <Shift-Button-4> [list $scrollByUnits %W h -5]
-	    bind Scrollbar <Shift-Button-5> [list $scrollByUnits %W h  5]
-
-	    if {[package vcompare $::tk_patchLevel "8.7a3"] >= 0} {
-		bind Scrollbar <Button-6>   [list $scrollByUnits %W h -5]
-		bind Scrollbar <Button-7>   [list $scrollByUnits %W h  5]
+		if {$::tk_patchLevel eq "8.7a3"} {
+		    bind Scrollbar <Button-6> {
+			scrollutil::condScrollByUnits %W hv -5
+		    }
+		    bind Scrollbar <Button-7> {
+			scrollutil::condScrollByUnits %W hv  5
+		    }
+		}
 	    }
 	}
     }
 
     set eventList [list <MouseWheel> <Shift-MouseWheel>]
-    switch $winSys {
-	aqua {
-	    lappend eventList <Option-MouseWheel> <Shift-Option-MouseWheel>
-	}
-	x11 {
-	    lappend eventList <Button-4> <Button-5> \
-			      <Shift-Button-4> <Shift-Button-5>
-	    if {[package vcompare $::tk_patchLevel "8.7a3"] >= 0} {
-		lappend eventList <Button-6> <Button-7>
+    if {$uniformWheelSupport} {
+	lappend eventList <Option-MouseWheel> <Shift-Option-MouseWheel>
+    } else {
+	switch $winSys {
+	    aqua {
+		lappend eventList <Option-MouseWheel> <Shift-Option-MouseWheel>
+	    }
+	    x11 {
+		lappend eventList \
+		    <Button-4> <Button-5> <Shift-Button-4> <Shift-Button-5>
+		if {$::tk_patchLevel eq "8.7a3"} {
+		    lappend eventList <Button-6> <Button-7>
+		}
 	    }
 	}
     }
@@ -97,30 +153,42 @@ proc scrollutil::createBindings {} {
     # Copy the mouse wheel event bindings of the widget
     # class Scrollbar to the binding tag TScrollbar
     #
+    bind TScrollbar <Enter> {+
+	if {![info exists tk::Priv(xEvents)]} {
+	    set scrollutil::xWheelEvents 0; set scrollutil::yWheelEvents 0
+	}
+    }
     foreach event $eventList {
 	bind TScrollbar $event [bind Scrollbar $event]
     }
 
-    if {$winSys eq "win32" && [package vcompare $::tk_patchLevel "8.6b2"] < 0} {
+    if {$winSys eq "win32" && ($::tk_version < 8.6 ||
+	[package vcompare $::tk_patchLevel "8.6b2"] < 0)} {
 	return ""
     }
 
+    #
+    # The rest is for scrollable widget containers.
+    #
+
     foreach event $eventList {
 	if {[string match <*Button-?> $event]} {
+	    ##nagelfar ignore
 	    bind WheeleventRedir $event [format {
 		if {![scrollutil::hasFocus %%W] ||
 		    ![scrollutil::isCompatible %s %%W]} {
 		    event generate [winfo toplevel %%W] %s \
-			  -rootx %%X -rooty %%Y
+			-rootx %%X -rooty %%Y
 		    break
 		}
 	    } $event $event]
 	} else {
+	    ##nagelfar ignore
 	    bind WheeleventRedir $event [format {
 		if {![scrollutil::hasFocus %%W] ||
 		    ![scrollutil::isCompatible %s %%W]} {
 		    event generate [winfo toplevel %%W] %s \
-			  -rootx %%X -rooty %%Y -delta %%D
+			-rootx %%X -rooty %%Y -delta %%D
 		    break
 		}
 	    } $event $event]
@@ -129,6 +197,28 @@ proc scrollutil::createBindings {} {
 	bind WheeleventBreak $event { break }
     }
 
+    variable touchpadScrollSupport
+    if {$touchpadScrollSupport} {
+	bind WheeleventRedir <TouchpadScroll> {
+	    if {![scrollutil::hasFocus %W] ||
+		![scrollutil::isCompatible <TouchpadScroll> %W]} {
+		lassign [tk::PreciseScrollDeltas %D] \
+		    scrollutil::dX scrollutil::dY
+		if {%# %% 5 == 0 && $scrollutil::dX != 0} {
+		    event generate [winfo toplevel %W] <Shift-MouseWheel> \
+			-rootx %X -rooty %Y -delta [expr {40 * $scrollutil::dX}]
+		}
+		if {%# %% 5 == 0 && $scrollutil::dY != 0} {
+		    event generate [winfo toplevel %W] <MouseWheel> \
+			-rootx %X -rooty %Y -delta [expr {40 * $scrollutil::dY}]
+		}
+		break
+	    }
+	}
+
+	bind WheeleventBreak <TouchpadScroll> { break }
+    }
+
     bind ScrlWidgetCont <Destroy> { scrollutil::onScrlWidgetContDestroy %W }
 
     bind WheeleventWidget <Destroy> {
@@ -180,17 +270,22 @@ proc scrollutil::addMouseWheelSupport {tag {axes "xy"}} {
     }
 
     variable winSys
+    variable uniformWheelSupport
 
     if {[string first "y" $axes] >= 0} {
-	if {$winSys eq "aqua"} {
+	if {$uniformWheelSupport} {
 	    bind $tag <MouseWheel> \
-		[format {%%W yview scroll [expr {-(%%D)}] units%s} $tail]
+		[format {mwutil::scrollByUnits %%W y %%D -40.0%s} $tail]
 	    bind $tag <Option-MouseWheel> \
-		[format {%%W yview scroll [expr {-10 * (%%D)}] units%s} $tail]
+		[format {mwutil::scrollByUnits %%W y %%D -12.0%s} $tail]
+	} elseif {$winSys eq "aqua"} {
+	    bind $tag <MouseWheel> \
+		[format {mwutil::scrollByUnits %%W y %%D  -1.0%s} $tail]
+	    bind $tag <Option-MouseWheel> \
+		[format {mwutil::scrollByUnits %%W y %%D  -0.1%s} $tail]
 	} else {
 	    bind $tag <MouseWheel> \
-		[format {%%W yview scroll [expr {%%D >= 0 ?\
-			 (-%%D) / 30 : (-(%%D) + 29) / 30}] units%s} $tail]
+		[format {mwutil::scrollByUnits %%W y %%D -30.0%s} $tail]
 
 	    if {$winSys eq "x11"} {
 		bind $tag <Button-4> \
@@ -202,15 +297,19 @@ proc scrollutil::addMouseWheelSupport {tag {axes "xy"}} {
     }
 
     if {[string first "x" $axes] >= 0} {
-	if {$winSys eq "aqua"} {
+	if {$uniformWheelSupport} {
 	    bind $tag <Shift-MouseWheel> \
-		[format {%%W xview scroll [expr {-(%%D)}] units%s} $tail]
+		[format {mwutil::scrollByUnits %%W x %%D -40.0%s} $tail]
 	    bind $tag <Shift-Option-MouseWheel> \
-		[format {%%W xview scroll [expr {-10 * (%%D)}] units%s} $tail]
+		[format {mwutil::scrollByUnits %%W x %%D -12.0%s} $tail]
+	} elseif {$winSys eq "aqua"} {
+	    bind $tag <Shift-MouseWheel> \
+		[format {mwutil::scrollByUnits %%W x %%D  -1.0%s} $tail]
+	    bind $tag <Shift-Option-MouseWheel> \
+		[format {mwutil::scrollByUnits %%W x %%D  -0.1%s} $tail]
 	} else {
 	    bind $tag <Shift-MouseWheel> \
-		[format {%%W xview scroll [expr {%%D >= 0 ?\
-			 (-%%D) / 30 : (-(%%D) + 29) / 30}] units%s} $tail]
+		[format {mwutil::scrollByUnits %%W x %%D -30.0%s} $tail]
 
 	    if {$winSys eq "x11"} {
 		bind $tag <Shift-Button-4> \
@@ -218,7 +317,7 @@ proc scrollutil::addMouseWheelSupport {tag {axes "xy"}} {
 		bind $tag <Shift-Button-5> \
 		    [format {%%W xview scroll  5 units%s} $tail]
 
-		if {[package vcompare $::tk_patchLevel "8.7a3"] >= 0} {
+		if {$::tk_patchLevel eq "8.7a3"} {
 		    bind $tag <Button-6> \
 			[format {%%W xview scroll -5 units%s} $tail]
 		    bind $tag <Button-7> \
@@ -227,6 +326,47 @@ proc scrollutil::addMouseWheelSupport {tag {axes "xy"}} {
 	    }
 	}
     }
+
+    variable touchpadScrollSupport
+    if {!$touchpadScrollSupport} {
+	return ""
+    }
+
+    set script "if {%# %% 5 != 0} "
+    append script [expr {$isWindow ? "break" : "return"}]
+    append script {
+	lassign [tk::PreciseScrollDeltas %D] scrollutil::dX scrollutil::dY
+    }
+    switch $axes {
+	xy {
+	    append script {
+		if {$scrollutil::dX != 0} {
+		    %W xview scroll [expr {-$scrollutil::dX}] units
+		}
+		if {$scrollutil::dY != 0} {
+		    %W yview scroll [expr {-$scrollutil::dY}] units
+		}
+	    }
+	}
+	x {
+	    append script {
+		if {$scrollutil::dX != 0} {
+		    %W xview scroll [expr {-$scrollutil::dX}] units
+		}
+	    }
+	}
+	y {
+	    append script {
+		if {$scrollutil::dY != 0} {
+		    %W yview scroll [expr {-$scrollutil::dY}] units
+		}
+	    }
+	}
+    }
+    if {$isWindow} {
+	append script break
+    }
+    bind $tag <TouchpadScroll> $script
 }
 
 #------------------------------------------------------------------------------
@@ -245,8 +385,10 @@ proc scrollutil::addMouseWheelSupport {tag {axes "xy"}} {
 proc scrollutil::createWheelEventBindings args {
     variable winSys
     if {$winSys eq "win32"} {
-	package require Tk 8.6b2
+	package require Tk 8.6b2-
     }
+    variable uniformWheelSupport
+    variable touchpadScrollSupport
 
     foreach tag $args {
 	if {[string match .* $tag]} {
@@ -262,54 +404,82 @@ proc scrollutil::createWheelEventBindings args {
 		path name of an existing toplevel widget"
 	}
 
-	if {$winSys eq "aqua"} {
+	if {$uniformWheelSupport} {
 	    bind $tag <MouseWheel> {
-		scrollutil::scrollByUnits %W %X %Y y [expr {-(%D)}]
+		scrollutil::scrollByUnits %W %X %Y y %D -40.0
 	    }
 	    bind $tag <Option-MouseWheel> {
-		scrollutil::scrollByUnits %W %X %Y y [expr {-10 * (%D)}]
+		scrollutil::scrollByUnits %W %X %Y y %D -12.0
 	    }
-
 	    bind $tag <Shift-MouseWheel> {
-		scrollutil::scrollByUnits %W %X %Y x [expr {-(%D)}]
+		scrollutil::scrollByUnits %W %X %Y x %D -40.0
 	    }
 	    bind $tag <Shift-Option-MouseWheel> {
-		scrollutil::scrollByUnits %W %X %Y x [expr {-10 * (%D)}]
+		scrollutil::scrollByUnits %W %X %Y x %D -12.0
+	    }
+	} elseif {$winSys eq "aqua"} {
+	    bind $tag <MouseWheel> {
+		scrollutil::scrollByUnits %W %X %Y y %D  -1.0
+	    }
+	    bind $tag <Option-MouseWheel> {
+		scrollutil::scrollByUnits %W %X %Y y %D  -0.1
+	    }
+	    bind $tag <Shift-MouseWheel> {
+		scrollutil::scrollByUnits %W %X %Y x %D  -1.0
+	    }
+	    bind $tag <Shift-Option-MouseWheel> {
+		scrollutil::scrollByUnits %W %X %Y x %D  -0.1
 	    }
 	} else {
 	    bind $tag <MouseWheel> {
-		scrollutil::scrollByUnits %W %X %Y y \
-		    [expr {%D >= 0 ? (-%D) / 30 : (-(%D) + 29) / 30}]
+		scrollutil::scrollByUnits %W %X %Y y %D -30.0
 	    }
 	    bind $tag <Shift-MouseWheel> {
-		scrollutil::scrollByUnits %W %X %Y x \
-		    [expr {%D >= 0 ? (-%D) / 30 : (-(%D) + 29) / 30}]
+		scrollutil::scrollByUnits %W %X %Y x %D -30.0
 	    }
 
 	    if {$winSys eq "x11"} {
 		bind $tag <Button-4> {
-		    scrollutil::scrollByUnits %W %X %Y y -5
+		    scrollutil::scrollByUnits %W %X %Y y -5 1.0
 		}
 		bind $tag <Button-5> {
-		    scrollutil::scrollByUnits %W %X %Y y  5
+		    scrollutil::scrollByUnits %W %X %Y y  5 1.0
 		}
 		bind $tag <Shift-Button-4> {
-		    scrollutil::scrollByUnits %W %X %Y x -5
+		    scrollutil::scrollByUnits %W %X %Y x -5 1.0
 		}
 		bind $tag <Shift-Button-5> {
-		    scrollutil::scrollByUnits %W %X %Y x  5
+		    scrollutil::scrollByUnits %W %X %Y x  5 1.0
 		}
 
-		if {[package vcompare $::tk_patchLevel "8.7a3"] >= 0} {
+		if {$::tk_patchLevel eq "8.7a3"} {
 		    bind $tag <Button-6> {
-			scrollutil::scrollByUnits %W %X %Y x -5
+			scrollutil::scrollByUnits %W %X %Y x -5 1.0
 		    }
 		    bind $tag <Button-7> {
-			scrollutil::scrollByUnits %W %X %Y x  5
+			scrollutil::scrollByUnits %W %X %Y x  5 1.0
 		    }
 		}
 	    }
 	}
+
+	if {$touchpadScrollSupport} {
+	    bind $tag <TouchpadScroll> {
+		if {%# %% 5 != 0} {
+		    continue
+		}
+		lassign [tk::PreciseScrollDeltas %D] \
+		    scrollutil::dX scrollutil::dY
+		if {$scrollutil::dX != 0} {
+		    event generate %W <Shift-MouseWheel> -rootx %X -rooty %Y \
+			-delta [expr {40 * $scrollutil::dX}]
+		}
+		if {$scrollutil::dY != 0} {
+		    event generate %W <MouseWheel> -rootx %X -rooty %Y \
+			-delta [expr {40 * $scrollutil::dY}]
+		}
+	    }
+	}
     }
 }
 
@@ -325,7 +495,7 @@ proc scrollutil::createWheelEventBindings args {
 proc scrollutil::enableScrollingByWheel args {
     variable winSys
     if {$winSys eq "win32"} {
-	package require Tk 8.6b2
+	package require Tk 8.6b2-
     }
 
     variable scrlWidgetContList
@@ -359,12 +529,48 @@ proc scrollutil::enableScrollingByWheel args {
     set scrlWidgetContList [lsort -command comparePaths $scrlWidgetContList]
 }
 
+#------------------------------------------------------------------------------
+# scrollutil::disableScrollingByWheel
+#
+# Usage: scrollutil::disableScrollingByWheel ?scrlWidgetCont scrlWidgetCont ...?
+#
+# Removes the specified scrollable widget containers from the internal list of
+# widget containers that are registered for scrolling by the mouse wheel event
+# bindings created by the createWheelEventBindings command.
+#------------------------------------------------------------------------------
+proc scrollutil::disableScrollingByWheel args {
+    variable winSys
+    if {$winSys eq "win32"} {
+	package require Tk 8.6b2-
+    }
+
+    variable scrlWidgetContList
+    foreach swc $args {
+	if {![winfo exists $swc]} {
+	    return -code error "bad window path name \"$swc\""
+	}
+
+	if {[set idx [lsearch -exact $scrlWidgetContList $swc]] < 0} {
+	    continue
+	}
+
+	set scrlWidgetContList [lreplace $scrlWidgetContList $idx $idx]
+
+	set tagList [bindtags $swc]
+	set idx [lsearch -exact $tagList "ScrlWidgetCont"]
+	bindtags $swc [lreplace $tagList $idx $idx]
+    }
+
+    set scrlWidgetContList [lsort -command comparePaths $scrlWidgetContList]
+}
+
 #------------------------------------------------------------------------------
 # scrollutil::adaptWheelEventHandling
 #
-# Usage: scrollutil::adaptWheelEventHandling ?widget widget ...?
+# Usage: scrollutil::adaptWheelEventHandling ?-ignorefocus? ?widget widget ...?
 #
-# For each widget argument, the command performs the following actions:
+# If the -ignorefocus option is not present then, for each widget argument, the
+# command performs the following actions:
 #
 #   * If $widget is a tablelist then it sets the latter's -xmousewheelwindow
 #     and -ymousewheelwindow options to the path name of the containing
@@ -386,11 +592,34 @@ proc scrollutil::enableScrollingByWheel args {
 #         the event will be redirected to the containing toplevel window via
 #         event generate rather than being handled by the binding script
 #         associated with the above-mentioned tag.
+#
+# If the -ignorefocus option is specified then, for each widget argument, the
+# command performs the following actions:
+#
+#   * If $widget is a tablelist then it resets the latter's -xmousewheelwindow
+#     and -ymousewheelwindow options (for Tablelist versions 6.4 and later).
+#
+#   * Otherwise it locates the (first) binding tag that has mouse wheel event
+#     bindings and is different from both the path name of the containing
+#     toplevel window and "all".  If the search for this tag was successful
+#     then the command modifies the widget's list of binding tags by appending
+#     the tag "WheeleventBreak" to this binding tag.  As a result, a mouse
+#     wheel event sent to this widget will be handled by the binding script
+#     associated with this tag and no further processing of the event will take
+#     place.
 #------------------------------------------------------------------------------
 proc scrollutil::adaptWheelEventHandling args {
     variable winSys
     if {$winSys eq "win32"} {
-	package require Tk 8.6b2
+	package require Tk 8.6b2-
+    }
+    variable uniformWheelSupport
+
+    set ignoreFocus 0
+    set arg0 [lindex $args 0]
+    if {[string length $arg0] > 1 && [string first $arg0 "-ignorefocus"] == 0} {
+	set ignoreFocus 1
+	set args [lrange $args 1 end]
     }
 
     foreach w $args {
@@ -398,27 +627,46 @@ proc scrollutil::adaptWheelEventHandling args {
 	    return -code error "bad window path name \"$w\""
 	}
 
+	set class [winfo class $w]
 	set wTop [winfo toplevel $w]
-	if {[winfo class $w] eq "Tablelist"} {
+	if {$class eq "Tablelist"} {
 	    if {[package vcompare $::tablelist::version "6.4"] >= 0} {
-		$w configure -xmousewheelwindow $wTop -ymousewheelwindow $wTop
+		if {$ignoreFocus} {
+		    $w configure -xmousewheelwindow "" -ymousewheelwindow ""
+		} else {
+		    $w configure -xmousewheelwindow $wTop \
+				 -ymousewheelwindow $wTop
+		}
 	    }
 	} else {
-	    set tagList [bindtags $w]
-	    if {[lsearch -exact $tagList "WheeleventRedir"] >= 0} {
-		continue
+	    set w2 [expr {$class eq "Ctext" ? "$w.t" : $w}]
+	    set tagList [bindtags $w2]
+	    foreach tag {WheeleventRedir WheeleventBreak} {
+		if {[set idx [lsearch -exact $tagList $tag]] >= 0} {
+		    set tagList [lreplace $tagList $idx $idx]
+		}
 	    }
 
 	    foreach tag $tagList {
-		if {$tag eq $wTop || $tag eq "all" ||
-		    ($winSys eq "x11" && [bind $tag <Button-4>] eq "") ||
-		    ($winSys ne "x11" && [bind $tag <MouseWheel>] eq "")} {
+		if {$winSys eq "x11" && !$uniformWheelSupport} {
+		    set hasWheelBindings [expr {[bind $tag <Button-4>] ne ""}]
+		} else {
+		    set hasWheelBindings [expr {
+			[bind $tag <MouseWheel>] ne "" ||
+			[bind $tag <TouchpadScroll>] ne ""}]
+		}
+		if {$tag eq $wTop || $tag eq "all" || !$hasWheelBindings} {
 		    continue
 		}
 
-		set tagIdx [lsearch -exact $tagList $tag]
-		bindtags $w [lreplace $tagList $tagIdx $tagIdx \
-			     WheeleventRedir $tag WheeleventBreak]
+		set idx [lsearch -exact $tagList $tag]
+		if {$ignoreFocus} {
+		    bindtags $w2 [lreplace $tagList $idx $idx \
+				  $tag WheeleventBreak]
+		} else {
+		    bindtags $w2 [lreplace $tagList $idx $idx \
+				  WheeleventRedir $tag WheeleventBreak]
+		}
 		break
 	    }
 	}
@@ -429,7 +677,11 @@ proc scrollutil::adaptWheelEventHandling args {
 	#
 	set sa [getscrollarea $w]
 	if {$sa ne ""} {
-	    adaptWheelEventHandling $sa.hsb $sa.vsb
+	    if {$ignoreFocus} {
+		adaptWheelEventHandling -ignorefocus $sa.hsb $sa.vsb
+	    } else {
+		adaptWheelEventHandling $sa.hsb $sa.vsb
+	    }
 	}
     }
 }
@@ -447,7 +699,7 @@ proc scrollutil::adaptWheelEventHandling args {
 proc scrollutil::setFocusCheckWindow args {
     variable winSys
     if {$winSys eq "win32"} {
-	package require Tk 8.6b2
+	package require Tk 8.6b2-
     }
 
     set argCount [llength $args]
@@ -500,7 +752,7 @@ proc scrollutil::setFocusCheckWindow args {
 proc scrollutil::focusCheckWindow w {
     variable winSys
     if {$winSys eq "win32"} {
-	package require Tk 8.6b2
+	package require Tk 8.6b2-
     }
 
     if {![winfo exists $w]} {
@@ -512,11 +764,112 @@ proc scrollutil::focusCheckWindow w {
 		  $focusCheckWinArr($w) : $w}]
 }
 
+#------------------------------------------------------------------------------
+# scrollutil::bindMouseWheel
+#
+# Usage: scrollutil::bindMouseWheel tag command
+#
+# Our own version of the ttk::bindMouseWheel procedure, which was not present
+# in tile before Dec. 2008.  Adds basic mouse wheel support to the specified
+# binding tag.
+#------------------------------------------------------------------------------
+proc scrollutil::bindMouseWheel {tag cmd} {
+    variable winSys
+    variable uniformWheelSupport
+
+    if {$cmd eq "break" || $cmd eq "continue" || $cmd eq ""} {
+	if {$uniformWheelSupport} {
+	    bind $tag <MouseWheel>		$cmd
+	    bind $tag <Option-MouseWheel>	$cmd
+	    bind $tag <Shift-MouseWheel>	$cmd
+	    bind $tag <Shift-Option-MouseWheel>	$cmd
+	} elseif {$winSys eq "aqua"} {
+	    bind $tag <MouseWheel>		$cmd
+	    bind $tag <Option-MouseWheel>	$cmd
+	    bind $tag <Shift-MouseWheel>	$cmd
+	    bind $tag <Shift-Option-MouseWheel>	$cmd
+	} else {
+	    bind $tag <MouseWheel>		$cmd
+	    bind $tag <Shift-MouseWheel>	$cmd
+
+	    if {$winSys eq "x11"} {
+		bind $tag <Button-4>		$cmd
+		bind $tag <Button-5>		$cmd
+		bind $tag <Shift-Button-4>	$cmd
+		bind $tag <Shift-Button-5>	$cmd
+
+		if {$::tk_patchLevel eq "8.7a3"} {
+		    bind $tag <Button-6>	$cmd
+		    bind $tag <Button-7>	$cmd
+		}
+	    }
+	}
+    } else {
+	if {$uniformWheelSupport} {
+	    bind $tag <MouseWheel>		"$cmd y %D -120.0"
+	    bind $tag <Option-MouseWheel>	"$cmd y %D -12.0"
+	    bind $tag <Shift-MouseWheel>	"$cmd x %D -120.0"
+	    bind $tag <Shift-Option-MouseWheel>	"$cmd x %D -12.0"
+	} elseif {$winSys eq "aqua"} {
+	    bind $tag <MouseWheel>		"$cmd y \[expr {-%D}\]"
+	    bind $tag <Option-MouseWheel>	"$cmd y \[expr {-10 * %D}\]"
+	    bind $tag <Shift-MouseWheel>	"$cmd x \[expr {-%D}\]"
+	    bind $tag <Shift-Option-MouseWheel>	"$cmd x \[expr {-10 * %D}\]"
+	} else {
+	    bind $tag <MouseWheel> \
+		"$cmd y \[expr {%D >= 0 ? -%D / 120 : (-%D + 119) / 120}\]"
+	    bind $tag <Shift-MouseWheel> \
+		"$cmd x \[expr {%D >= 0 ? -%D / 120 : (-%D + 119) / 120}\]"
+
+	    if {$winSys eq "x11"} {
+		bind $tag <Button-4>		"$cmd y -1"
+		bind $tag <Button-5>		"$cmd y +1"
+		bind $tag <Shift-Button-4>	"$cmd x -1"
+		bind $tag <Shift-Button-5>	"$cmd x +1"
+
+		if {$::tk_patchLevel eq "8.7a3"} {
+		    bind $tag <Button-6>	"$cmd x -1"
+		    bind $tag <Button-7>	"$cmd x +1"
+		}
+	    }
+	}
+    }
+}
+
 #
 # Private procedures
 # ==================
 #
 
+#------------------------------------------------------------------------------
+# scrollutil::condScrollByUnits
+#------------------------------------------------------------------------------
+proc scrollutil::condScrollByUnits {w orient amount {divisor 1.0}} {
+    if {![info exists ::tk::Priv(xEvents)]} {
+	#
+	# Count both the <MouseWheel> and <Shift-MouseWheel>
+	# events, and ignore the non-dominant ones
+	#
+	variable xWheelEvents
+	variable yWheelEvents
+	set axis [expr {[string index $orient 0] eq "h" ? "x" : "y"}]
+	incr ${axis}WheelEvents
+	if {($xWheelEvents + $yWheelEvents > 10) &&
+	    ($axis eq "x" && $xWheelEvents < $yWheelEvents ||
+	     $axis eq "y" && $yWheelEvents < $xWheelEvents)} {
+	    return ""
+	}
+    }
+
+    variable uniformWheelSupport
+    variable scrollByUnitsProc
+    if {$uniformWheelSupport} {
+	$scrollByUnitsProc $w $orient $amount $divisor
+    } else {						
+	$scrollByUnitsProc $w $orient $amount
+    }
+}
+
 #------------------------------------------------------------------------------
 # scrollutil::hasFocus
 #------------------------------------------------------------------------------
@@ -547,21 +900,14 @@ proc scrollutil::hasFocus w {
 # scrollutil::isCompatible
 #------------------------------------------------------------------------------
 proc scrollutil::isCompatible {event w} {
-    set tagList [bindtags $w]
-    set idx [lsearch -exact $tagList "WheeleventRedir"]
-    set tag [lindex $tagList [incr idx]]
-    if {[bind $tag $event] eq ""} {
-	return 0
-    } elseif {[string match "*Scrollbar" [winfo class $w]]} {
-	set orient [$w cget -orient]
-	return [expr {
-	    ($orient eq "horizontal" &&  ([string match {<Shift-*>} $event] \
-	     || [string match {<Button-[67]>} $event])) ||
-	    ($orient eq "vertical"   && !([string match {<Shift-*>} $event] \
-	     || [string match {<Button-[67]>} $event]))
-	}]
-    } else {
+    if {[string match "*Scrollbar" [winfo class $w]] &&
+	[string match {<Shift-*>} $event]} {
 	return 1
+    } else {
+	set tagList [bindtags $w]
+	set idx [lsearch -exact $tagList "WheeleventRedir"]
+	set tag [lindex $tagList [incr idx]]
+	return [expr {[bind $tag $event] ne ""}]
     }
 }
 
@@ -581,13 +927,16 @@ proc scrollutil::comparePaths {w1 w2} {
 #------------------------------------------------------------------------------
 # scrollutil::scrollByUnits
 #------------------------------------------------------------------------------
-proc scrollutil::scrollByUnits {w rootX rootY axis units} {
+proc scrollutil::scrollByUnits {w rootX rootY axis delta divisor} {
     set w [winfo containing -displayof $w $rootX $rootY]
     variable scrlWidgetContList
     foreach swc $scrlWidgetContList {
 	if {[mayScroll $swc $w]} {
-	    $swc ${axis}view scroll $units units
-	    return ""
+	    set number [expr {$delta/$divisor}]
+	    set number \
+		[expr {int($number > 0 ? ceil($number) : floor($number))}]
+	    $swc ${axis}view scroll $number units
+	    return -code break ""
 	}
     }
 }
