@@ -4,11 +4,11 @@
 # Copyright (c) 2019-2024  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
-package require Tk 8.4-
+package require -exact scrollutil::common 2.4
+
 if {$::tk_version < 8.5 || [regexp {^8\.5a[1-5]$} $::tk_patchLevel]} {
-    package require tile 0.8-
+    package require tile 0.6[::scrollutil::-]
 }
-package require -exact scrollutil::common 2.1
 
 package provide scrollutil_tile $::scrollutil::version
 package provide Scrollutil_tile $::scrollutil::version
