@@ -1,12 +1,12 @@
 #==============================================================================
-# Contains Wcb procedures for Tk or tile entry, BWidget Entry, Tk or tile
-# spinbox, and tile combobox widgets.
+# Contains Wcb procedures for Tk or Ttk entry, BWidget Entry, Tk or Ttk
+# spinbox, and Ttk combobox widgets.
 #
-# REMARK: Everything stated below for entry widgets is valid for tile entry and
+# REMARK: Everything stated below for entry widgets is valid for Ttk entry and
 #         BWidget Entry widgets, too.  Similarly, everything stated below for
-#         spinbox widgets is valid for tile spinbox widgets, too.
+#         spinbox widgets is valid for Ttk spinbox widgets, too.
 #
-# Copyright (c) 1999-2022  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 1999-2023  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
 #
@@ -18,29 +18,23 @@ namespace eval wcb {
     #
     # Some regexp patterns:
     #
-    if {$::tk_version >= 8.1} {
-	variable alphaPat	{^[[:alpha:]]*$}
-	variable digitPat	{^[[:digit:]]*$}
-	variable alnumPat	{^[[:alnum:]]*$}
-    } else {
-	variable alphaPat	{^[A-Za-z]*$}
-	variable digitPat	{^[0-9]*$}
-	variable alnumPat	{^[A-Za-z0-9]*$}
-    }
+    variable alphaPat	{^[[:alpha:]]*$}
+    variable digitPat	{^[[:digit:]]*$}
+    variable alnumPat	{^[[:alnum:]]*$}
 }
 
 #
-# Utility procedures for entry, spinbox, and tile combobox widgets
-# ================================================================
+# Utility procedures for entry, spinbox, and Ttk combobox widgets
+# ===============================================================
 #
 
 #------------------------------------------------------------------------------
 # wcb::changeEntryText
 #
-# Replaces the text of the entry, spinbox, or tile combobox widget w with the
+# Replaces the text of the entry, spinbox, or Ttk combobox widget w with the
 # string str, by using the delete and insert operations.  If one of these
 # subcommands is canceled by some before-callback then the procedure keeps the
-# original entry, spinbox, or tile combobox string and returns 0, otherwise it
+# original entry, spinbox, or Ttk combobox string and returns 0, otherwise it
 # returns 1.
 #------------------------------------------------------------------------------
 proc wcb::changeEntryText {w str} {
@@ -67,7 +61,7 @@ proc wcb::changeEntryText {w str} {
 # wcb::postInsertEntryLen
 #
 # Returns the length of the text that would be contained in the entry, spinbox,
-# or tile combobox widget w after inserting the string str.
+# or Ttk combobox widget w after inserting the string str.
 #------------------------------------------------------------------------------
 proc wcb::postInsertEntryLen {w str} {
     return [expr {[$w index end] + [string length $str]}]
@@ -76,7 +70,7 @@ proc wcb::postInsertEntryLen {w str} {
 #------------------------------------------------------------------------------
 # wcb::postInsertEntryText
 #
-# Returns the text that would be contained in the entry, spinbox, or tile
+# Returns the text that would be contained in the entry, spinbox, or Ttk
 # combobox widget w after inserting the string str before the character
 # indicated by the index idx.
 #------------------------------------------------------------------------------
@@ -93,7 +87,7 @@ proc wcb::postInsertEntryText {w idx str} {
 #------------------------------------------------------------------------------
 # wcb::postDeleteEntryText
 #
-# Returns the text that would be contained in the entry, spinbox, or tile
+# Returns the text that would be contained in the entry, spinbox, or Ttk
 # combobox widget w after deleting the range of characters starting with the
 # index given by from and stopping just before the one given by the first
 # element of args (if any).
@@ -113,14 +107,14 @@ proc wcb::postDeleteEntryText {w from args} {
 
 #
 # Simple before-insert callback routines for
-# entry, spinbox, and tile combobox widgets
+# entry, spinbox, and Ttk combobox widgets
 # ==========================================
 #
 
 #------------------------------------------------------------------------------
 # wcb::checkStrForRegExp
 #
-# Checks whether the string str to be inserted into the entry, spinbox, or tile
+# Checks whether the string str to be inserted into the entry, spinbox, or Ttk
 # combobox widget w is matched by the regular expression exp; if not, it
 # cancels the insert operation.
 #------------------------------------------------------------------------------
@@ -133,7 +127,7 @@ proc wcb::checkStrForRegExp {exp w idx str} {
 #------------------------------------------------------------------------------
 # wcb::checkStrForAlpha
 #
-# Checks whether the string str to be inserted into the entry, spinbox, or tile
+# Checks whether the string str to be inserted into the entry, spinbox, or Ttk
 # combobox widget w is alphabetic; if not, it cancels the insert operation.
 #------------------------------------------------------------------------------
 proc wcb::checkStrForAlpha {w idx str} {
@@ -144,7 +138,7 @@ proc wcb::checkStrForAlpha {w idx str} {
 #------------------------------------------------------------------------------
 # wcb::checkStrForNum
 #
-# Checks whether the string str to be inserted into the entry, spinbox, or tile
+# Checks whether the string str to be inserted into the entry, spinbox, or Ttk
 # combobox widget w is numeric; if not, it cancels the insert operation.
 #------------------------------------------------------------------------------
 proc wcb::checkStrForNum {w idx str} {
@@ -155,7 +149,7 @@ proc wcb::checkStrForNum {w idx str} {
 #------------------------------------------------------------------------------
 # wcb::checkStrForAlnum
 #
-# Checks whether the string str to be inserted into the entry, spinbox, or tile
+# Checks whether the string str to be inserted into the entry, spinbox, or Ttk
 # combobox widget w is alphanumeric; if not, it cancels the insert operation.
 #------------------------------------------------------------------------------
 proc wcb::checkStrForAlnum {w idx str} {
@@ -166,7 +160,7 @@ proc wcb::checkStrForAlnum {w idx str} {
 #------------------------------------------------------------------------------
 # wcb::convStrToUpper
 #
-# Replaces the string str to be inserted into the entry, spinbox, or tile
+# Replaces the string str to be inserted into the entry, spinbox, or Ttk
 # combobox widget w with its uppercase equivalent.
 #------------------------------------------------------------------------------
 proc wcb::convStrToUpper {w idx str} {
@@ -177,7 +171,7 @@ proc wcb::convStrToUpper {w idx str} {
 #------------------------------------------------------------------------------
 # wcb::convStrToLower
 #
-# Replaces the string str to be inserted into the entry, spinbox, or tile
+# Replaces the string str to be inserted into the entry, spinbox, or Ttk
 # combobox widget w with its lowercase equivalent.
 #------------------------------------------------------------------------------
 proc wcb::convStrToLower {w idx str} {
@@ -187,14 +181,14 @@ proc wcb::convStrToLower {w idx str} {
 
 #
 # Further before-insert callback routines for
-# entry, spinbox, and tile combobox widgets
+# entry, spinbox, and Ttk combobox widgets
 # ===========================================
 #
 
 #------------------------------------------------------------------------------
 # wcb::checkEntryForInt
 #
-# Checks whether the text contained in the entry, spinbox, or tile combobox
+# Checks whether the text contained in the entry, spinbox, or Ttk combobox
 # widget w after inserting the string str before the character indicated by the
 # index idx would represent (the starting part of) an integer number; if not,
 # it cancels the insert operation.
@@ -209,7 +203,7 @@ proc wcb::checkEntryForInt {w idx str} {
 #------------------------------------------------------------------------------
 # wcb::checkEntryForUInt
 #
-# Checks whether the text contained in the entry, spinbox, or tile combobox
+# Checks whether the text contained in the entry, spinbox, or Ttk combobox
 # widget w after inserting the string str before the character indicated by the
 # index idx would represent (the starting part of) an unsigned integer no
 # greater than max; if not, it cancels the insert operation.  The value * for
@@ -219,7 +213,8 @@ proc wcb::checkEntryForUInt {max w idx str} {
     set newText [postInsertEntryText $w $idx $str]
     if {![regexp {^[0-9]*$} $newText]} {
 	cancel
-    } elseif {[string compare $max *] != 0} {
+    } elseif {$max ne "*"} {
+	##nagelfar ignore
 	scan $newText "%d" val
 	if {$val > $max} {
 	    cancel
@@ -230,7 +225,7 @@ proc wcb::checkEntryForUInt {max w idx str} {
 #------------------------------------------------------------------------------
 # wcb::checkEntryForReal
 #
-# Checks whether the text contained in the entry, spinbox, or tile combobox
+# Checks whether the text contained in the entry, spinbox, or Ttk combobox
 # widget w after inserting the string str before the character indicated by the
 # index idx would represent (the starting part of) a real number; if not, it
 # cancels the insert operation.
@@ -245,7 +240,7 @@ proc wcb::checkEntryForReal {w idx str} {
 #------------------------------------------------------------------------------
 # wcb::checkEntryForFixed
 #
-# Checks whether the text contained in the entry, spinbox, or tile combobox
+# Checks whether the text contained in the entry, spinbox, or Ttk combobox
 # widget w after inserting the string str before the character indicated by the
 # index idx would represent (the starting part of) a real number with at most
 # cnt digits after the decimal point; if not, it cancels the insert operation.
@@ -254,7 +249,7 @@ proc wcb::checkEntryForReal {w idx str} {
 #------------------------------------------------------------------------------
 proc wcb::checkEntryForFixed {cnt w idx str} {
     set pattern {^[+-]?[0-9]*\.?}
-    if {[string compare $cnt "*"] == 0} {
+    if {$cnt eq "*"} {
 	append pattern {[0-9]*$}
     } else {
 	for {set n 0} {$n < $cnt} {incr n} {
@@ -273,7 +268,7 @@ proc wcb::checkEntryForFixed {cnt w idx str} {
 # wcb::checkEntryLen
 #
 # Checks whether the length of the text contained in the entry, spinbox, or
-# tile combobox widget w after inserting the string str would be greater than
+# Ttk combobox widget w after inserting the string str would be greater than
 # len; if yes, it cancels the insert operation.
 #------------------------------------------------------------------------------
 proc wcb::checkEntryLen {len w idx str} {
@@ -290,10 +285,10 @@ proc wcb::checkEntryLen {len w idx str} {
 #------------------------------------------------------------------------------
 # wcb::entryWidgetCmd
 #
-# Processes the Tcl command corresponding to an entry, spinbox, or tile
-# combobox widget w with registered callbacks.  In this procedure, the
-# execution of the commands insert, delete, and icursor is preceded by calls to
-# the corresponding before-callbacks and followed by calls to the corresponding
+# Processes the Tcl command corresponding to an entry, spinbox, or Ttk combobox
+# widget w with registered callbacks.  In this procedure, the execution of the
+# commands insert, delete, and icursor is preceded by calls to the
+# corresponding before-callbacks and followed by calls to the corresponding
 # after-callbacks, in the global scope.
 #------------------------------------------------------------------------------
 proc wcb::entryWidgetCmd {w argList} {
