@@ -1,2 +1,2 @@
-if {![package vsatisfies [package provide Tcl] 8.5]} {return}
+if {![package vsatisfies [package provide Tcl] 8.5-]} {return}
 package ifneeded widgetPlus 1.0b2 [list source [file join $dir widgetPlus.tcl]]
